==> pwsafe-3.24.1-src.zip: pwsafe-3.24.1-src/src/core/core.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_EXPORTHEADER               3002
#define IDSC_EXPHDRGROUPTITLE           3003
#define IDSC_EXPHDRUSERNAME             3004
#define IDSC_EXPHDRPASSWORD             3005
#define IDSC_EXPHDRURL                  3006
#define IDSC_EXPHDRAUTOTYPE             3007
#define IDSC_EXPHDRCTIME                3008
#define IDSC_EXPHDRPMTIME               3009
#define IDSC_EXPHDRATIME                3010
#define IDSC_EXPHDRXTIME                3011
#define IDSC_EXPHDRRMTIME               3012
#define IDSC_EXPHDRPWHISTORY            3013
#define IDSC_EXPHDRNOTES                3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_LOCKUNKNOWNERROR           3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_MSXMLPARSEERROR            3043
#define IDSC_MSXMLBADCREATESCHEMA       3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOMSXMLREADER              3047
#define IDSC_XMLHEADER                  3048
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_XMLSAVEFAILURE             3051
#define IDSC_SAXERRORPWH                3052
#define IDSC_MSXMLSAXGENERROR           3053
#define IDSC_XERCESSAXGENERROR          3054
#define IDSC_EXPHDRGROUP                3055
#define IDSC_EXPHDRTITLE                3056
#define IDSC_EXPHDRPWPOLICY             3057
#define IDSC_EXPHDRXTIMEINT             3058
#define IDSC_XERCESPARSEERROR           3059
#define IDCS_XERCESEXCEPTION            3060
#define IDCS_XERCESOUTOFMEMORY          3061
#define IDSC_EXPHDRRUNCOMMAND           3063
#define IDSC_EXPHDRDCA                  3064
#define IDSC_EXPHDREMAIL                3065

#define IDSC_CONFIG_NONE                3230
#define IDSC_CONFIG_REGISTRY            3231
#define IDSC_CONFIG_FILE_RO             3232
#define IDSC_CONFIG_FILE_RW             3233

#define IDSC_IMPORTNUMBER               3240
#define IDSC_IMPORTFAILURE              3241
#define IDSC_IMPORTHDR                  3242
#define IDSC_IMPORTMISSINGCOLS          3243
#define IDSC_IMPORTNOCOLS               3244
#define IDSC_READ_ERROR                 3245
#define IDSC_ENCODING_PROBLEM           3246

#define IDSC_FILEREADONLY               3247
#define IDSC_FILEEXISTS                 3248
#define IDSC_INVALIDFLAG                3249
#define IDSC_NOMOREHANDLES              3250
#define IDSC_FILEPATHNOTFOUND           3102
#define IDSC_BADPASSWORD                3251

#define IDSC_REPORTFILENAME             3252
#define IDSC_REPORT_TITLE1              3253
#define IDSC_REPORT_TITLE2              3254
#define IDSC_START_REPORT               3255
#define IDSC_END_REPORT1                3256
#define IDSC_END_REPORT2                3257

#define IDSC_IMPORTNOHEADER             3258
#define IDSC_IMPORTLINESKIPPED          3259
#define IDSC_IMPORTKNOWNHDRS            3260
#define IDSC_IMPORTEMPTYLINESKIPPED     3261
#define IDSC_PWHERRORLINE               3262
#define IDSC_PWHISTORYSKIPPED           3263
#define IDSC_IMPORTCONFLICTS1           3264
#define IDSC_IMPORTCONFLICTS2           3265
#define IDSC_IMPORTINVALIDFIELD         3266
#define IDSC_IMPORTNOPASSWORD           3268
#define IDSC_IMPORTNOTITLE              3269
#define IDSC_VALIDATEUUID               3270
#define IDSC_VALIDATEPWH                3271
#define IDSC_IMPORTWARNINGHDR           3272
#define IDSC_IMPORTWARNING1             3273
#define IDSC_IMPORTWARNING1A            3274
#define IDSC_IMPORTWARNING2             3275
#define IDSC_IMPORTWARNING2A            3276
#define IDSC_IMPORTWARNING3             3277
#define IDSC_ALIAS                      3278
#define IDSC_SHORTCUT                   3279
#define IDSC_FNORMAL                    3281
#define IDSC_FALIAS                     3282
#define IDSC_FSHORTCUT                  3283
#define IDSC_FALIASBASE                 3284
#define IDSC_FSHORTCUTBASE              3285
#define IDSC_EQUALS                     3286
#define IDSC_DOESNOTEQUAL               3287
#define IDSC_BEGINSWITH                 3288
#define IDSC_DOESNOTBEGINSWITH          3289
#define IDSC_ENDSWITH                   3290
#define IDSC_DOESNOTENDWITH             3291
#define IDSC_CONTAINS                   3292
#define IDSC_DOESNOTCONTAIN             3293
#define IDSC_IS                         3294
#define IDSC_ISNOT                      3295
#define IDSC_ISPRESENT                  3296
#define IDSC_ISNOTPRESENT               3297
#define IDSC_ISACTIVE                   3298
#define IDSC_ISINACTIVE                 3299
#define IDSC_SET                        3300
#define IDSC_NOTSET                     3301
#define IDSC_INVALID                    3302
#define IDSC_BETWEEN                    3303
#define IDSC_LESSTHAN                   3304
#define IDSC_LESSTHANEQUAL              3305
#define IDSC_GREATERTHAN                3306
#define IDSC_GREATERTHANEQUAL           3307
#define IDSC_BEFORE                     3308
#define IDSC_AFTER                      3309
#define IDSC_CASE_INSENSITIVE           3310
#define IDSC_CASE_SENSITIVE             3311
#define IDSC_EXPIRED                    3312
#define IDSC_WILLEXPIRE                 3313
#define IDSC_EXPIRE_IN_DAYS             3314
#define IDSC_SEEPWHISTORYFILTERS        3315
#define IDSC_SEEPWPOLICYFILTERS         3316
#define IDSC_CANTPROCESSDBFILTERS       3317
#define IDSC_INVALID_SCHEMA             3318
#define IDSC_INVALID_SCHEMA_VER         3319
#define IDSC_MISSING_SCHEMA_VER         3320
#define IDSC_MISSING_XML_VER            3321
#define IDSC_INVALID_XML_VER1           3322
#define IDSC_INVALID_XML_VER2           3323
#define IDSC_AND                        3324
#define IDSC_OR                         3325
#define IDSC_XMLLOCK_CFG_FAILED         3326
#define IDSC_XMLCREATE_CFG_FAILED       3327
#define IDSC_SAX2FATALERROR             3328
#define IDSC_SAX2ERROR                  3329
#define IDSC_SAX2WARNING                3330
#define IDSC_FILTEREXISTS               3331
#define IDSC_MISSINGXSD                 3345
#define IDSC_CANTVALIDATEXML            3346
#define IDSC_FILTERSKEPT                3347
#define IDSC_EXS_INPUTEMPTY             3350
#define IDSC_EXS_VARNAMEEMPTY           3351
#define IDSC_EXS_FIRSTNOTALPHA          3352
#define IDSC_EXS_VARNAMEINVALID         3353
#define IDSC_EXS_MISSINGCURLYBKT        3354
#define IDSC_EXS_MISSINGSQUAREBKT       3355
#define IDSC_EXS_INVALIDINDEX           3356
#define IDSC_EXS_INDEXNOTNUMERIC        3357
#define IDSC_EXS_UNMATCHEDQUOTES        3358
#define IDSC_EXS_INVALIDBRACKETS        3359
#define IDSC_EXS_MISSINGROUNDBKT        3360
#define IDSC_UNKNOWN                    3361
#define IDSC_XMLEXP_PREFERENCES         3362
#define IDSC_XMLEXP_FILTERACTIVE        3363
#define IDSC_XMLEXP_FLDRESTRICT         3364
#define IDSC_XMLEXP_SUBSETACTIVE        3365
#define IDSC_XMLEXP_SUBSETFIELDS        3366
#define IDSC_UNKNOWNFUNCTION            3367
#define IDSC_UNKNOWNOBJECT              3368
#define IDSC_FSCLEAN                    3369
#define IDSC_FSADDED                    3370
#define IDSC_FSMODIFIED                 3371
#define IDSC_IMPORTENTRY                3372
#define IDSC_IMPORTPSWDNOCOLS           3373
#define IDSC_IMPORTRECNOTFOUND          3374
#define IDSC_IMPORTKNOWNHDRS2           3375
#define IDSC_IMPORT_ON_LINE             3376
#define IDSC_IMPORT_ENTRY_ID            3377
#define IDSC_FILEWRITEERROR             3378
#define IDSC_YES                        3379
#define IDSC_NO                         3380
#define IDSC_NONE                       3381
#define IDSC_USERONHOST                 3382
#define IDSC_UNKNOWNFIELDS              3383
#define IDSC_IMPORTCONFLICTS0           3384
#define IDSC_IMPORTCONFLICTSX1          3385
#define IDSC_IMPORTCONFLICTSX2          3386
#define IDSC_DUPLICATENUMBER            3387
#define IDSC_VALIDATEDUPLICATES         3388
#define IDSC_IMPORTRECSKIPPED           3389
#define IDSC_VALIDATETEXT               3390
#define IDSC_VALIDATEENTRY              3391
#define IDSC_VALIDATEENTRY2             3392
#define IDSC_WARNINGENTRYLENGTH         3393
#define IDSC_ENTRY                      3394
#define IDSC_ENTRIES                    3395
#define IDSC_LARGEENTRIES               3396
#define IDSC_RELATIVE                   3397
#define IDSC_FILE_UNREADABLE            3398

#define IDSC_DELETEBASET                3400
#define IDSC_DELETEABASE                3401
#define IDSC_DELETESBASE                3402
#define IDSC_ALIASES                    3403
#define IDSC_SHORTCUTS                  3404

// Keep DCA together
#define IDSC_CURRENTDEFAULTDCA          4000
#define IDSC_DCABROWSE                  4001
#define IDSC_DCAAUTOTYPE                4002
#define IDSC_DCACOPYNOTES               4003
#define IDSC_DCACOPYPASSWORD            4004
#define IDSC_DCACOPYUSERNAME            4005
#define IDSC_DCAVIEWEDIT                4006
#define IDSC_DCACOPYPASSWORDMIN         4007
#define IDSC_DCABROWSEPLUS              4008
#define IDSC_DCARUN                     4009
#define IDSC_DCASENDEMAIL               4010

==> pwsafe-3.25-src.zip: pwsafe-3.25-src/src/core/core.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_EXPORTHEADER               3002
#define IDSC_FLDNMGROUPTITLE            3003
#define IDSC_FLDNMUSERNAME              3004
#define IDSC_FLDNMPASSWORD              3005
#define IDSC_FLDNMURL                   3006
#define IDSC_FLDNMAUTOTYPE              3007
#define IDSC_FLDNMCTIME                 3008
#define IDSC_FLDNMPMTIME                3009
#define IDSC_FLDNMATIME                 3010
#define IDSC_FLDNMXTIME                 3011
#define IDSC_FLDNMRMTIME                3012
#define IDSC_FLDNMPWHISTORY             3013
#define IDSC_FLDNMNOTES                 3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_LOCKUNKNOWNERROR           3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_MSXMLPARSEERROR            3043
#define IDSC_MSXMLBADCREATESCHEMA       3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOMSXMLREADER              3047
#define IDSC_XMLHEADER                  3048
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_XMLSAVEFAILURE             3051
#define IDSC_SAXERRORPWH                3052
#define IDSC_MSXMLSAXGENERROR           3053
#define IDSC_XERCESSAXGENERROR          3054
#define IDSC_FLDNMGROUP                 3055
#define IDSC_FLDNMTITLE                 3056
#define IDSC_FLDNMPWPOLICY              3057
#define IDSC_FLDNMXTIMEINT              3058
#define IDSC_XERCESPARSEERROR           3059
#define IDCS_XERCESEXCEPTION            3060
#define IDCS_XERCESOUTOFMEMORY          3061
#define IDSC_FLDNMRUNCOMMAND            3063
#define IDSC_FLDNMDCA                   3064
#define IDSC_FLDNMEMAIL                 3065
#define IDSC_FLDNMPROTECTED             3066
#define IDSC_FLDNMUUID                  3067

#define IDSC_CONFIG_NONE                3230
#define IDSC_CONFIG_REGISTRY            3231
#define IDSC_CONFIG_FILE_RO             3232
#define IDSC_CONFIG_FILE_RW             3233

#define IDSC_IMPORTNUMBER               3240
#define IDSC_IMPORTFAILURE              3241
#define IDSC_IMPORTHDR                  3242
#define IDSC_IMPORTMISSINGCOLS          3243
#define IDSC_IMPORTNOCOLS               3244
#define IDSC_READ_ERROR                 3245
#define IDSC_ENCODING_PROBLEM           3246

#define IDSC_FILEREADONLY               3247
#define IDSC_FILEEXISTS                 3248
#define IDSC_INVALIDFLAG                3249
#define IDSC_NOMOREHANDLES              3250
#define IDSC_FILEPATHNOTFOUND           3102
#define IDSC_BADPASSWORD                3251

#define IDSC_REPORTFILENAME             3252
#define IDSC_REPORT_TITLE1              3253
#define IDSC_REPORT_TITLE2              3254
#define IDSC_START_REPORT               3255
#define IDSC_END_REPORT1                3256
#define IDSC_END_REPORT2                3257

#define IDSC_IMPORTNOHEADER             3258
#define IDSC_IMPORTLINESKIPPED          3259
#define IDSC_IMPORTKNOWNHDRS            3260
#define IDSC_IMPORTEMPTYLINESKIPPED     3261
#define IDSC_PWHERRORLINE               3262
#define IDSC_PWHISTORYSKIPPED           3263
#define IDSC_IMPORTCONFLICTS1           3264
#define IDSC_IMPORTCONFLICTS2           3265
#define IDSC_IMPORTINVALIDFIELD         3266
#define IDSC_IMPORTNOPASSWORD           3268
#define IDSC_IMPORTNOTITLE              3269
#define IDSC_VALIDATEUUID               3270
#define IDSC_VALIDATEPWH                3271
#define IDSC_IMPORTWARNINGHDR           3272
#define IDSC_IMPORTWARNING1             3273
#define IDSC_IMPORTWARNING1A            3274
#define IDSC_IMPORTWARNING2             3275
#define IDSC_IMPORTWARNING2A            3276
#define IDSC_IMPORTWARNING3             3277
#define IDSC_ALIAS                      3278
#define IDSC_SHORTCUT                   3279
#define IDSC_FNORMAL                    3281
#define IDSC_FALIAS                     3282
#define IDSC_FSHORTCUT                  3283
#define IDSC_FALIASBASE                 3284
#define IDSC_FSHORTCUTBASE              3285
#define IDSC_EQUALS                     3286
#define IDSC_DOESNOTEQUAL               3287
#define IDSC_BEGINSWITH                 3288
#define IDSC_DOESNOTBEGINSWITH          3289
#define IDSC_ENDSWITH                   3290
#define IDSC_DOESNOTENDWITH             3291
#define IDSC_CONTAINS                   3292
#define IDSC_DOESNOTCONTAIN             3293
#define IDSC_IS                         3294
#define IDSC_ISNOT                      3295
#define IDSC_ISPRESENT                  3296
#define IDSC_ISNOTPRESENT               3297
#define IDSC_ISACTIVE                   3298
#define IDSC_ISINACTIVE                 3299
#define IDSC_SET                        3300
#define IDSC_NOTSET                     3301
#define IDSC_INVALID                    3302
#define IDSC_BETWEEN                    3303
#define IDSC_LESSTHAN                   3304
#define IDSC_LESSTHANEQUAL              3305
#define IDSC_GREATERTHAN                3306
#define IDSC_GREATERTHANEQUAL           3307
#define IDSC_BEFORE                     3308
#define IDSC_AFTER                      3309
#define IDSC_CASE_INSENSITIVE           3310
#define IDSC_CASE_SENSITIVE             3311
#define IDSC_EXPIRED                    3312
#define IDSC_WILLEXPIRE                 3313
#define IDSC_EXPIRE_IN_DAYS             3314
#define IDSC_SEEPWHISTORYFILTERS        3315
#define IDSC_SEEPWPOLICYFILTERS         3316
#define IDSC_CANTPROCESSDBFILTERS       3317
#define IDSC_INVALID_SCHEMA             3318
#define IDSC_INVALID_SCHEMA_VER         3319
#define IDSC_MISSING_SCHEMA_VER         3320
#define IDSC_MISSING_XML_VER            3321
#define IDSC_INVALID_XML_VER1           3322
#define IDSC_INVALID_XML_VER2           3323
#define IDSC_AND                        3324
#define IDSC_OR                         3325
#define IDSC_XMLLOCK_CFG_FAILED         3326
#define IDSC_XMLCREATE_CFG_FAILED       3327
#define IDSC_SAX2FATALERROR             3328
#define IDSC_SAX2ERROR                  3329
#define IDSC_SAX2WARNING                3330
#define IDSC_FILTEREXISTS               3331
#define IDSC_MISSINGXSD                 3345
#define IDSC_CANTVALIDATEXML            3346
#define IDSC_FILTERSKEPT                3347
#define IDSC_EXS_INPUTEMPTY             3350
#define IDSC_EXS_VARNAMEEMPTY           3351
#define IDSC_EXS_FIRSTNOTALPHA          3352
#define IDSC_EXS_VARNAMEINVALID         3353
#define IDSC_EXS_MISSINGCURLYBKT        3354
#define IDSC_EXS_MISSINGSQUAREBKT       3355
#define IDSC_EXS_INVALIDINDEX           3356
#define IDSC_EXS_INDEXNOTNUMERIC        3357
#define IDSC_EXS_UNMATCHEDQUOTES        3358
#define IDSC_EXS_INVALIDBRACKETS        3359
#define IDSC_EXS_MISSINGROUNDBKT        3360
#define IDSC_UNKNOWN                    3361
#define IDSC_XMLEXP_PREFERENCES         3362
#define IDSC_XMLEXP_FILTERACTIVE        3363
#define IDSC_XMLEXP_FLDRESTRICT         3364
#define IDSC_XMLEXP_SUBSETACTIVE        3365
#define IDSC_XMLEXP_SUBSETFIELDS        3366
#define IDSC_UNKNOWNFUNCTION            3367
#define IDSC_UNKNOWNOBJECT              3368
#define IDSC_FSCLEAN                    3369
#define IDSC_FSADDED                    3370
#define IDSC_FSMODIFIED                 3371
#define IDSC_IMPORTENTRY                3372
#define IDSC_IMPORTPSWDNOCOLS           3373
#define IDSC_IMPORTRECNOTFOUND          3374
#define IDSC_IMPORTKNOWNHDRS2           3375
#define IDSC_IMPORT_ON_LINE             3376
#define IDSC_IMPORT_ENTRY_ID            3377
#define IDSC_FILEWRITEERROR             3378
#define IDSC_YES                        3379
#define IDSC_NO                         3380
#define IDSC_NONE                       3381
#define IDSC_USERONHOST                 3382
#define IDSC_UNKNOWNFIELDS              3383
#define IDSC_IMPORTCONFLICTS0           3384
#define IDSC_IMPORTCONFLICTSX1          3385
#define IDSC_IMPORTCONFLICTSX2          3386
#define IDSC_DUPLICATENUMBER            3387
#define IDSC_VALIDATEDUPLICATES         3388
#define IDSC_IMPORTRECSKIPPED           3389
#define IDSC_VALIDATETEXT               3390
#define IDSC_VALIDATEENTRY              3391
#define IDSC_VALIDATEENTRY2             3392
#define IDSC_WARNINGENTRYLENGTH         3393
#define IDSC_ENTRY                      3394
#define IDSC_ENTRIES                    3395
#define IDSC_LARGEENTRIES               3396
#define IDSC_RELATIVE                   3397
#define IDSC_FILE_UNREADABLE            3398

#define IDSC_DELETEBASET                3400
#define IDSC_DELETEABASE                3401
#define IDSC_DELETESBASE                3402
#define IDSC_ALIASES                    3403
#define IDSC_SHORTCUTS                  3404

#define IDSC_WAS                        3410
#define IDSC_WERE                       3411
#define IDSC_SYNCHUPDATED               3412
#define IDSC_SYNCHCOMPLETED             3413
#define IDSC_MERGECONFLICTS             3414
#define IDSC_MERGECOMPLETED             3415
#define IDSC_CONFLICT                   3416
#define IDSC_CONFLICTS                  3417
#define IDSC_MERGED                     3418
#define IDSC_MERGEADDED                 3419

// Keep DCA together
#define IDSC_CURRENTDEFAULTDCA          4000
#define IDSC_DCABROWSE                  4001
#define IDSC_DCAAUTOTYPE                4002
#define IDSC_DCACOPYNOTES               4003
#define IDSC_DCACOPYPASSWORD            4004
#define IDSC_DCACOPYUSERNAME            4005
#define IDSC_DCAVIEWEDIT                4006
#define IDSC_DCACOPYPASSWORDMIN         4007
#define IDSC_DCABROWSEPLUS              4008
#define IDSC_DCARUN                     4009
#define IDSC_DCASENDEMAIL               4010
